/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.connect.container.worker.utils;

import io.fogsy.empire.core.empire.annotation.InvalidRdfException;
import org.apache.streampipes.model.connect.adapter.*;
import org.apache.streampipes.serializers.jsonld.JsonLdTransformer;
import org.apache.streampipes.vocabulary.StreamPipes;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;

public class Utils {

    public static String getMinimalStreamAdapterJsonLD() {
        return getMinimalAdapterJsonLD(new GenericAdapterStreamDescription(), StreamPipes.GENERIC_ADAPTER_SET_DESCRIPTION);
    }

    public static String getMinimalSetAdapterJsonLD() {
        return getMinimalAdapterJsonLD(new GenericAdapterSetDescription(), StreamPipes.GENERIC_ADAPTER_SET_DESCRIPTION);
    }

    private static String getMinimalAdapterJsonLD(AdapterDescription asd, String rootElement) {
        String id = "http://t.de/";
        asd.setUri(id);
        asd.setId(id);

        JsonLdTransformer jsonLdTransformer = new JsonLdTransformer(rootElement);

        try {
            return org.apache.streampipes.commons.Utils.asString(jsonLdTransformer.toJsonLd(asd));
        } catch (IllegalAccessException | InvocationTargetException | ClassNotFoundException e) {
            e.printStackTrace();
        }
        catch (InvalidRdfException e) {
            e.printStackTrace();
        }

        return "";
    }


    public static AdapterStreamDescription getMinimalStreamAdapter() {
        AdapterStreamDescription result = new GenericAdapterStreamDescription();
        String id = "http://t.de/";
        result.setUri(id);
        result.setId(id);
        result.setRules(new ArrayList<>());

        return result;
    }

    public static AdapterSetDescription getMinimalSetAdapter() {
        AdapterSetDescription result = new GenericAdapterSetDescription();
        String id = "http://t.de/";
        result.setUri(id);
        result.setId(id);

        return result;
    }

}
